@@ -1,20 +1,9 @@
-/* This file is part of the KDE libraries
-   Copyright (C) 2005-2006 Olivier Goffart <ogoffart at kde.org>
-   Copyright (C) 2013-2015 Martin Klapetek <mklapetek@kde.org>
+/*
+    This file is part of the KDE libraries
+    SPDX-FileCopyrightText: 2005-2006 Olivier Goffart <ogoffart at kde.org>
+    SPDX-FileCopyrightText: 2013-2015 Martin Klapetek <mklapetek@kde.org>
 
-   This library is free software; you can redistribute it and/or
-   modify it under the terms of the GNU Library General Public
-   License version 2 as published by the Free Software Foundation.
-
-   This library is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   Library General Public License for more details.
-
-   You should have received a copy of the GNU Library General Public License
-   along with this library; see the file COPYING.LIB.  If not, write to
-   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02110-1301, USA.
+    SPDX-License-Identifier: LGPL-2.0-only
 */
 
 #ifndef KNOTIFICATION_H
@@ -45,7 +34,7 @@ class QWidget;
  * window. This allows us to play sounds when a dialog appears.
  * This is an instant notification.  It ends automatically after a small timeout.
  *
- * @li persistant notifications:
+ * @li Persistent notifications:
  * Notify when the user received a new message, or when something else important happened
  * the user has to know about.  This notification has a start and a end.  It begins when
  * the event actually occurs, and finishes when the message is acknowledged or read.
@@ -78,7 +67,7 @@ class QWidget;
  * @warning Notifications won't be visible otherwise.
  *
  * You can do this with the following CMake command:
- * install(FILES appname.notifyrc  DESTINATION ${KNOTIFYRC_INSTALL_DIR}))
+ * install(FILES appname.notifyrc DESTINATION ${KNOTIFYRC_INSTALL_DIR}))
  *
  *  This file contains  mainly 3 parts
  *   <ol><li>\ref global "Global information"</li>
@@ -90,13 +79,23 @@ class QWidget;
  * <pre>
            [Global]
            IconName=Filename
-           Comment=Friendly Name of app
-           Name=Name of app
+           Name=Name of Application
+           DesktopEntry=DesktopFileName
+           Comment=A brief description of the application
  * </pre>
- *   The icon filename is just the name, without extension,  it's found with the KIconLoader.
- *   The Comment field will be used in KControl to describe the application.
- *   The Name field is optional and may be used as the application name for popup,
- *   if Name is not present, Comment is used instead
+ *   The icon filename is just the name, without extension. It follows the same
+ *   behavior as `Icon=` as defined in the Freedesktop Desktop Entry specification.
+ *   The Name field may be used as the application name for popup, it may also be used
+ *   to visualize the application's notification settings in KCModule instances.
+ *   If Name is not present, Comment is used instead. Either must be present.
+ *   Make sure to follow <a href="https://hig.kde.org/style/writing/capitalization.html">the HIG</a>
+ *
+ *   The DesktopEntry field is required in order for the application to be listed
+ *   in the notifications KCModule, and for its notifications to appear in the
+ *   notification history. Ensure that its value matches the application's desktop
+ *   file name, that the desktop file name is set in the QGuiApplication or
+ *   KAboutData desktopFileName property, and that the desktop file is not marked
+ *   as Hidden.
  *
  * \subsection context Context information
  *
@@ -111,20 +110,20 @@ class QWidget;
  *  </pre>
  *  The second part of the groupname is the context identifier.
  *  It should not contain special characters.
- *  The Name field is the one the user will see (and which is translated)
+ *  The Name field is required and used for visualization.
  *
  * \subsection events Definition of Events
  *
  * The definition of the events forms the most important part of the config file
  * <pre>
            [Event/newmail]
-           Name=New email
+           Name=New E-Mail
            Comment=You have got a new email
            Contexts=folder,group
            Action=Sound|Popup
 
            [Event/contactOnline]
-           Name=Contact goes online
+           Name=Contact Goes Online
            Comment=One of your contact has been connected
            Contexts=group
            Sound=filetoplay.ogg
@@ -172,7 +171,8 @@ class QWidget;
  * This portion of code will fire the event for the "contactOnline" event
  *
  * @code
-    KNotification *notification= new KNotification ( "contactOnline", widget );
+    KNotification *notification= new KNotification ( "contactOnline" );
+    notification->setWidget( widget );
     notification->setText( i18n("The contact <i>%1</i> has gone online", contact->name() );
     notification->setPixmap( contact->pixmap() );
     notification->setActions( QStringList( i18n( "Open chat" ) ) );
@@ -295,6 +295,7 @@ public:
         CriticalUrgency = 90
     };
 
+#if KNOTIFICATIONS_ENABLE_DEPRECATED_SINCE(5, 75)
     /**
      * Create a new notification.
      *
@@ -309,8 +310,32 @@ public:
      * @param eventId is the name of the event
      * @param widget is a widget where the notification reports to
      * @param flags is a bitmask of NotificationFlag
+     * @deprecated Since 5.75, use other constructor and call setWidget() explicitly
      */
-    explicit KNotification(const QString &eventId, QWidget *widget = nullptr, const NotificationFlags &flags = CloseOnTimeout);
+    KNOTIFICATIONS_DEPRECATED_VERSION(5, 75, "Use other constructor and call setWidget() explicitly")
+    explicit KNotification(const QString &eventId, QWidget *widget, const NotificationFlags &flags = CloseOnTimeout);
+#endif
+
+    /**
+     * Create a new notification.
+     *
+     * You have to use sendEvent to show the notification.
+     *
+     * The pointer is automatically deleted when the event is closed.
+     *
+     * The NotificationFlags is set to CloseOnTimeout.
+     *
+     * @param eventId is the name of the event
+     * @since 5.75
+     */
+    inline explicit KNotification(const QString &eventId)
+        : KNotification(eventId, CloseOnTimeout, nullptr)
+    {
+    }
+    // TODO KF6: remove thic constructor, in favour of other non-deprecated constructor
+    // It is a helper constructor for software binary compatibility of code which called the
+    // deprecated constructor so far due to it's second parameter "widget" having had
+    // a default nullptr value.
 
     /**
      * Create a new notification.
@@ -329,13 +354,8 @@ public:
      * @param flags is a bitmask of NotificationFlag
      * @param parent parent object
      */
-    // KDE5: Clean up this mess
-    // Only this constructor should stay with saner argument order and
-    // defaults. Because of binary and source compatibility issues it has to
-    // stay this way for now. The second argument CANNOT have a default
-    // argument. if someone needs a widget associated with the notification he
-    // should use setWidget after creating the object (or some xyz_cast magic)
     explicit KNotification(const QString &eventId, const NotificationFlags &flags, QObject *parent = nullptr);
+    // TODO KF6: pass flags by value instead of reference, set CloseOnTimeout as default value
 
     ~KNotification();
 
@@ -569,10 +589,14 @@ public:
     QString appName() const;
 
 Q_SIGNALS:
+#if KNOTIFICATIONS_ENABLE_DEPRECATED_SINCE(5, 76)
     /**
      * Emitted only when the default activation has occurred
+     * @deprecated Since 5.67, use defaultActivated() instead
      */
+    KNOTIFICATIONS_DEPRECATED_VERSION_BELATED(5, 76, 5, 67, "Use defaultActivated() instead")
     void activated();
+#endif
 
     /**
      * Emitted when the default action has been activated.
